@@ -142,10 +142,13 @@ class PyScanner(MF):
             return MF.import_hook(self, name, caller, *arg, **karg) 
 
     def __call__(self, node, env, path):
-        if str(node).split('.')[-1] not in ['py', 'pyc', 'pyo']: return []
-        self.modules = {}; self.name = str(node)
+        if str(node).split('.')[-1] not in ['py', 'pyc', 'pyo', 'scons', 'pyscons']: return []
+        self.modules = {}; 
+        self.name = str(node)
+
         try: self.run_script(self.name)
         except: pass
+
         imports = [m.__file__ for m in self.modules.values() if m.__file__ != None]
         imports = list(os.path.abspath(m) for m in imports if self.path_filter(m))
         return imports
@@ -210,7 +213,7 @@ class PYTOOL:
 
     def __call__(self, env):
         env.Append(SCANNERS = Scanner(function = PyScanner(self.path_filter), 
-                    name = "PyScanner", skeys = ['.py', '.pyo', '.pyc'], recursive=self.recursive))
+                    name = "PyScanner", skeys = ['.scons', '.pyscons', '.py', '.pyo', '.pyc'], recursive=self.recursive))
         env.AddMethod(_PyScript, "PyScript")
         env.AddMethod(_PyScons, "PyScons")
         return env
